@@ -1,12 +1,12 @@
 #!/bin/sh
 set -ev
 
-DARCS=$PWD/../darcs
+test $DARCS || DARCS=$PWD/../darcs
 
 rm -rf fooOld tempA tempB
 mkdir fooOld tempA tempB
 cd fooOld
-$DARCS inittree
+$DARCS init
 echo record author me > _darcs/prefs/defaults
 echo ALL all >> _darcs/prefs/defaults
 #echo ALL verbose >> _darcs/prefs/defaults
@@ -17,7 +17,7 @@ $DARCS record -m Old
 cd ..
 
 cd tempA
-$DARCS inittree
+$DARCS init
 cp ../fooOld/_darcs/prefs/defaults _darcs/prefs
 $DARCS pull ../fooOld
 echo A > foo
@@ -25,7 +25,7 @@ $DARCS record -m A
 cd ..
 
 cd tempB
-$DARCS inittree
+$DARCS init
 cp ../fooOld/_darcs/prefs/defaults _darcs/prefs
 $DARCS pull ../fooOld
 echo B > foo
@@ -57,3 +57,4 @@ cd ..
 cmp tempB/foo tempA/foo
 
 rm -rf fooOld tempA tempB
+
